==> tekton-model-triggers-v1alpha1-6.5.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerTemplateListFluent<A extends TriggerTemplateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,TriggerTemplate item);
  public A setToItems(Integer index,TriggerTemplate item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A addAllToItems(Collection<TriggerTemplate> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A removeAllFromItems(Collection<TriggerTemplate> items);
  public A removeMatchingFromItems(Predicate<TriggerTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerTemplate> getItems();
  public List<TriggerTemplate> buildItems();
  public TriggerTemplate buildItem(Integer index);
  public TriggerTemplate buildFirstItem();
  public TriggerTemplate buildLastItem();
  public TriggerTemplate buildMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public A withItems(List<TriggerTemplate> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public Boolean hasItems();
  public TriggerTemplateListFluent.ItemsNested<A> addNewItem();
  public TriggerTemplateListFluent.ItemsNested<A> addNewItemLike(TriggerTemplate item);
  public TriggerTemplateListFluent.ItemsNested<A> setNewItemLike(Integer index,TriggerTemplate item);
  public TriggerTemplateListFluent.ItemsNested<A> editItem(Integer index);
  public TriggerTemplateListFluent.ItemsNested<A> editFirstItem();
  public TriggerTemplateListFluent.ItemsNested<A> editLastItem();
  public TriggerTemplateListFluent.ItemsNested<A> editMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,TriggerTemplateFluent<TriggerTemplateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerTemplateListFluent<A extends TriggerTemplateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,TriggerTemplate item);
  public A setToItems(int index,TriggerTemplate item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A addAllToItems(Collection<TriggerTemplate> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A removeAllFromItems(Collection<TriggerTemplate> items);
  public A removeMatchingFromItems(Predicate<TriggerTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerTemplate> getItems();
  public List<TriggerTemplate> buildItems();
  public TriggerTemplate buildItem(int index);
  public TriggerTemplate buildFirstItem();
  public TriggerTemplate buildLastItem();
  public TriggerTemplate buildMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public A withItems(List<TriggerTemplate> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public Boolean hasItems();
  public TriggerTemplateListFluent.ItemsNested<A> addNewItem();
  public TriggerTemplateListFluent.ItemsNested<A> addNewItemLike(TriggerTemplate item);
  public TriggerTemplateListFluent.ItemsNested<A> setNewItemLike(int index,TriggerTemplate item);
  public TriggerTemplateListFluent.ItemsNested<A> editItem(int index);
  public TriggerTemplateListFluent.ItemsNested<A> editFirstItem();
  public TriggerTemplateListFluent.ItemsNested<A> editLastItem();
  public TriggerTemplateListFluent.ItemsNested<A> editMatchingItem(Predicate<TriggerTemplateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,TriggerTemplateFluent<TriggerTemplateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
